/* gTask
 * Copyright (C) 2004 Michael Henson                                       
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef GTASK_CONNECTION_GROUP_H
#define GTASK_CONNECTION_GROUP_H

#include <glib.h>
#include <glib-2.0/glib-object.h>

#include <gtask/gtask-connection.h>

/** @addtogroup GTaskConnectionGroup */

/* @{ */

typedef struct _GTaskConnectionGroup        GTaskConnectionGroup;
typedef struct _GTaskConnectionGroupPrivate GTaskConnectionGroupPrivate;
typedef struct _GTaskConnectionGroupClass   GTaskConnectionGroupClass;

/** returns the GType of GTaskConnectionGroup */
#define GTASK_CONNECTION_GROUP_TYPE            (gtask_connection_group_get_type())

/** casts the passed in object to a GTaskConnectionGroup */
#define GTASK_CONNECTION_GROUP(obj)            (G_TYPE_CHECK_INSTANCE_CAST( (obj), \
                                                GTASK_CONNECTION_GROUP_TYPE, \
                                                GTaskConnectionGroup ))

/** casts the passed in object to a GTaskConnectionGroupClass */
#define GTASK_CONNECTION_GROUP_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST( (klass), \
                                                GTASK_CONNECTION_GROUP_TYPE, \
                                                GTaskConnectionGroupClass ))

/**
 * returns TRUE if the passed in object is a GTaskConnectionGroup,
 * FALSE otherwise
 */
#define GTASK_IS_CONNECTION_GROUP(obj)         (G_TYPE_CHECK_INSTANCE_TYPE( (obj), \
                                                GTASK_CONNECTION_GROUP_TYPE ))

/**
 * returns TRUE if the passed in object is a GTaskConnectionGroupClass,
 * FALSE otherwise
 */
#define GTASK_IS_CONNECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE( (klass), \
                                                GTASK_CONNECTION_GROUP_TYPE ))

#define GTASK_CONNECTION_GROUP_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS( (obj), \
                                                GTASK_CONNECTION_GROUP_TYPE, \
                                                GTaskConnectionGroupClass ))

/**
 * A struct to hold private information for a GTaskConnectionGroup.
 */
struct _GTaskConnectionGroupPrivate {
    /// Stores a list of GTaskConnection objects
    GSList   *connection_list;
    gboolean  dispose_has_run;
};

/**
 * A struct intended to represent a group of connections that
 * tasks, packets, etc will serialize to by default
 */
struct _GTaskConnectionGroup {
    GObject                      parent;
    GTaskConnectionGroupPrivate *private;
};

struct _GTaskConnectionGroupClass {
    GObjectClass parent;
};

GType gtask_connection_group_get_type( void );

GTaskConnectionGroup *
gtask_connection_group_new( void );

void
gtask_connection_group_add_connection( GTaskConnectionGroup *group,
                                       GTaskConnection *conn );

void
gtask_connection_group_clear( GTaskConnectionGroup *group );

GSList *
gtask_connection_group_get_list( GTaskConnectionGroup *group );

GTaskConnection *
gtask_connection_group_get_connection_by_name( GTaskConnectionGroup *group,
                                               const gchar *conn_name );

/* @} */

#endif
