/* gTask
 * Copyright (C) 2004 Michael Henson                                       
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef GTASK_ERROR_PACKET_H
#define GTASK_ERROR_PACKET_H

#include <gtask/gtask-packet.h>

/** @addtogroup GTaskErrorPacket */

/* @{ */

typedef struct _GTaskErrorPacket        GTaskErrorPacket;
typedef struct _GTaskErrorPacketPrivate GTaskErrorPacketPrivate;
typedef struct _GTaskErrorPacketClass   GTaskErrorPacketClass;


/** returns the GType of GTaskErrorPacket */
#define GTASK_ERROR_PACKET_TYPE            (gtask_error_packet_get_type())

/** casts the passed in object to a GTaskErrorPacket */
#define GTASK_ERROR_PACKET(obj)            (G_TYPE_CHECK_INSTANCE_CAST( (obj), \
                                            GTASK_ERROR_PACKET_TYPE, \
                                            GTaskErrorPacket ))

/** casts the passed in object to a GTaskErrorPacketClass */
#define GTASK_ERROR_PACKET_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST( (klass), \
                                            GTASK_ERROR_PACKET_TYPE, \
                                            GTaskErrorPacketClass ))

/**
 * returns TRUE if the passed in object is a GTaskErrorPacket,
 * FALSE otherwise
 */
#define GTASK_IS_ERROR_PACKET(obj)         (G_TYPE_CHECK_INSTANCE_TYPE( (obj), \
                                            GTASK_ERROR_PACKET_TYPE ))

/**
 * returns TRUE if the passed in object is a GTaskErrorPacketClass,
 * FALSE otherwise
 */
#define GTASK_IS_ERROR_PACKET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE( (klass), \
                                            GTASK_ERROR_PACKET_TYPE ))

#define GTASK_ERROR_PACKET_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS( (obj), \
                                            GTASK_ERROR_PACKET_TYPE, \
                                            GTaskErrorPacketClass ))

typedef enum {
    GTASK_ERROR_NONE,
    GTASK_ERROR_UNDEFINED
} GTaskErrorType;

struct _GTaskErrorPacket {
    GTaskPacket              parent;
    GTaskErrorPacketPrivate *private;
};

struct _GTaskErrorPacketPrivate {
    GTaskErrorType  error;
    GString        *error_msg;
};

struct _GTaskErrorPacketClass {
    GTaskPacketClass parent;
};

GType gtask_error_packet_get_type( void );

GTaskErrorPacket *
gtask_error_packet_new( void );

GTaskErrorType
gtask_error_packet_get_error_type( GTaskErrorPacket *packet );

void
gtask_error_packet_set_error_type( GTaskErrorPacket *packet,
                                   GTaskErrorType error );

const char *
gtask_error_packet_get_error_message( GTaskErrorPacket *packet );

void
gtask_error_packet_set_error_message( GTaskErrorPacket *packet,
                                      const char *error_msg );

/* @} */

#endif
