/* gTask
 * Copyright (C) 2004 Michael Henson                                       
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef GTASK_EVENT_DISPATCHER_H
#define GTASK_EVENT_DISPATCHER_H

#include <gtask/gtask-stream-parser.h>
#include <glib.h>

/** @addtogroup GTaskEventDispatcher */

/* @{ */

typedef struct _GTaskEventDispatcher        GTaskEventDispatcher;
typedef struct _GTaskEventDispatcherPrivate GTaskEventDispatcherPrivate;
typedef struct _GTaskEventDispatcherClass   GTaskEventDispatcherClass;

/** returns the GType of GTaskEventDispatcher */
#define GTASK_EVENT_DISPATCHER_TYPE        (gtask_event_dispatcher_get_type())

/** casts the passed in object to a GTaskEventDispatcher */
#define GTASK_EVENT_DISPATCHER(obj)        (G_TYPE_CHECK_INSTANCE_CAST( (obj), \
                                            GTASK_EVENT_DISPATCHER_TYPE, \
                                            GTaskEventDispatcher ))

/** casts the passed in object to a GTaskEventDispatcherClass */
#define GTASK_EVENT_DISPATCHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST( (klass), \
                                             GTASK_EVENT_DISPATCHER_TYPE, \
                                             GTaskEventDispatcherClass ))

/**
 * returns TRUE if the passed in object is a GTaskEventDispatcher,
 * FALSE otherwise
 */
#define GTASK_IS_EVENT_DISPATCHER(obj)     (G_TYPE_CHECK_INSTANCE_TYPE( (obj), \
                                            GTASK_EVENT_DISPATCHER_TYPE ))

/**
 * returns TRUE if the passed in object is a GTaskEventDispatcherClass,
 * FALSE otherwise
 */
#define GTASK_IS_EVENT_DISPATCHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE( (klass), \
                                                GTASK_EVENT_DISPATCHER_TYPE ))

#define GTASK_EVENT_DISPATCHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS( (obj), \
                                               GTASK_EVENT_DISPATCHER_TYPE, \
                                               GTaskEventDispatcherClass ))

/**
 * A struct to hold private information for a GTaskEventDispatcher.
 */
struct _GTaskEventDispatcherPrivate {
    GTaskStreamParser *parser;

    guint              next_watch_id;

    GArray            *watches;

    gboolean           dispose_has_run;
};

struct _GTaskEventDispatcher {
    GObject                      parent;
    GTaskEventDispatcherPrivate *private;
};

struct _GTaskEventDispatcherClass {
    GObjectClass parent;
};

typedef gboolean (*GTaskEventFunc) ( GTaskEventDispatcher *,
                                     GObject *,
                                     gpointer );

GType gtask_event_dispatcher_get_type( void );

GTaskEventDispatcher *
gtask_event_dispatcher_new_with_parser( GTaskStreamParser *parser );

guint
gtask_event_dispatcher_add_watch( GTaskEventDispatcher *dispatch,
                                  GType watch_type,
                                  GTaskEventFunc func,
                                  gpointer user_data );

void
gtask_event_dispatcher_remove_watch( GTaskEventDispatcher *dispatch,
                                     guint watch_id );

GTaskStreamParser *
gtask_event_dispatcher_get_stream_parser( GTaskEventDispatcher *dispatch );

gboolean
gtask_event_dispatcher_private_parse_callback( GIOChannel *chann,
                                               GIOCondition cond,
                                               gpointer data );

/* @} */

#endif
