/* gTask
 * Copyright (C) 2004 Michael Henson                                       
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef GTASK_FACTORY_H
#define GTASK_FACTORY_H

#include <glib-2.0/glib-object.h>

#include <gtask/gtask-generic-task.h>
#include <gtask/gtask-connection-group.h>

/** addtogroup GTaskFactory */

/* @{ */

typedef struct _GTaskFactory        GTaskFactory;
typedef struct _GTaskFactoryPrivate GTaskFactoryPrivate;
typedef struct _GTaskFactoryClass   GTaskFactoryClass;

/** returns the GType of GTaskFactory */
#define GTASK_FACTORY_TYPE          (gtask_factory_get_type())

/** casts the passed in object to a GTaskFactory */
#define GTASK_FACTORY(obj)          (G_TYPE_CHECK_INSTANCE_CAST( (obj), \
                                     GTASK_FACTORY_TYPE, \
                                     GTaskFactory ))

/** casts the passed in object to a GTaskFactory */
#define GTASK_FACTORY_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST( (klass), \
                                       GTASK_FACTORY_TYPE, \
                                       GTaskFactoryClass ))

/**
 * returns TRUE if the passed in object is a GTaskFactory,
 * FALSE otherwise
 */
#define GTASK_IS_FACTORY(obj)         (G_TYPE_CHECK_INSTANCE_TYPE( (obj), \
                                       GTASK_FACTORY_TYPE ))

/**
 * returns TRUE if the passed in object is a GTaskFactoryClass
 * FALSE otherwise
 */
#define GTASK_IS_FACTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE( (klass), \
                                       GTASK_FACTORY_TYPE ))

#define GTASK_FACTORY_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS( (obj), \
                                       GTASK_FACTORY_TYPE, \
                                       GTaskFactoryClass ))

struct _GTaskFactory {
    GObject              parent;
    GTaskFactoryPrivate *private;
};

struct _GTaskFactoryPrivate {
    GTaskConnectionGroup *conn_group;
    GString              *application;
    GString              *program;
    guint                 last_task_id;
    gboolean              dispose_has_run;
};

struct  _GTaskFactoryClass {
    GObjectClass parent;
};

GType gtask_factory_get_type( void );

GTaskFactory *
gtask_factory_new( void );

GTaskFactory *
gtask_factory_new_with_resources( GTaskConnectionGroup *conn_group,
                                  const gchar *program,
                                  const gchar *application );

const gchar *
gtask_factory_get_program( GTaskFactory *factory );

void
gtask_factory_set_program( GTaskFactory *factory, const gchar *program );

const gchar *
gtask_factory_get_application( GTaskFactory *factory );

void
gtask_factory_set_application( GTaskFactory *factory, const gchar *application );

GTaskGenericTask *
gtask_factory_create_task( GTaskFactory *factory, gchar *task_type );

GTaskConnectionGroup *
gtask_factory_get_connection_group( GTaskFactory *factory );

void
gtask_factory_set_connection_group( GTaskFactory *factory,
                                    GTaskConnectionGroup *conn_group );

/* @} */

#endif
