/* gTask
 * Copyright (C) 2004 Michael Henson                                       
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef GTASK_FILE_H
#define GTASK_FILE_H

/** @addtogroup GTaskFile */

#include <glib-2.0/glib-object.h>
#include <glib/gstring.h>

/* @{ */

typedef struct _GTaskFile        GTaskFile;
typedef struct _GTaskFilePrivate GTaskFilePrivate;
typedef struct _GTaskFileClass   GTaskFileClass;

/** returns a GType of GTaskFile */
#define GTASK_FILE_TYPE            (gtask_file_get_type())

/** casts the passed in object to a GTaskFile */
#define GTASK_FILE(obj)            (G_TYPE_CHECK_INSTANCE_CAST( (obj), \
                                            GTASK_FILE_TYPE, \
                                            GTaskFile))

/** casts the passed in object to a GTaskFileClass */
#define GTASK_FILE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST( (klass), \
                                            GTASK_FILE_TYPE, \
                                            GTaskFileClass ))

/**
 * returns TRUE if the passed in object is a GTaskFile,
 * FALSE otherwise
 * */
#define GTASK_IS_FILE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE( (obj), \
                                            GTASK_FILE_TYPE ))

/**
 * returns TRUE if the passed in object is a GTaskFileClass,
 * FALSE otherwise
 */
#define GTASK_IS_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE( (klass), \
                                            GTASK_FILE_TYPE ))

#define GTASK_FILE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS( (obj), \
                                            GTASK_FILE_TYPE, \
                                            GTaskGenericClass ))

struct _GTaskFilePrivate {
    GString  *uri;
    GString  *thumbnail_uri;
    GString  *mime_type;

    GString  *description;

    gboolean  completed;
};

struct _GTaskFile {
    GObject parent;
    GTaskFilePrivate *private;
};

struct _GTaskFileClass {
    GObjectClass parent;
};

GType gtask_file_get_type( void );

GTaskFile *
gtask_file_new( void );

GTaskFile *
gtask_file_new_with_properties( const char *uri,
                                const char *mime_type,
                                const char *thumbnail_uri,
                                const char *description );

void
gtask_file_set_uri( GTaskFile *file, const char *uri );

const char *
gtask_file_get_uri( GTaskFile *file );

void
gtask_file_set_mime_type( GTaskFile *file, const char *mime_type );

const char *
gtask_file_get_mime_type( GTaskFile *file );

void
gtask_file_set_thumbnail_uri( GTaskFile *file, const char *thumbnail_uri );

const char *
gtask_file_get_thumbnail_uri( GTaskFile *file );

void
gtask_file_set_completed( GTaskFile *file, gboolean completed );

gboolean
gtask_file_get_completed( GTaskFile *file );

void
gtask_file_set_description( GTaskFile *file, const char *description );

const char *
gtask_file_get_description( GTaskFile *file );

/* @} */

#endif
