/* gTask
 * Copyright (C) 2004 Michael Henson                                       
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef GTASK_GENERIC_TASK_H
#define GTASK_GENERIC_TASK_H

#include <glib-2.0/glib-object.h>
#include <glib/glist.h>
#include <libxml/tree.h>

#include <gtask/gtask-connection-group.h>
#include <gtask/gtask-file.h>


/** @addtogroup GTaskGenericTask */

/* @{ */

typedef struct _GTaskGenericTask        GTaskGenericTask;
typedef struct _GTaskGenericTaskPrivate GTaskGenericTaskPrivate;
typedef struct _GTaskGenericTaskClass   GTaskGenericTaskClass;

/** returns a GType of GTaskGenericTask */
#define GTASK_GENERIC_TASK_TYPE            (gtask_generic_task_get_type())

/** casts the passed in object to a GTaskGenericTask */
#define GTASK_GENERIC_TASK(obj)            (G_TYPE_CHECK_INSTANCE_CAST( (obj), \
                                            GTASK_GENERIC_TASK_TYPE, \
                                            GTaskGenericTask))

/** casts the passed in object to a GTaskGenericTaskClass */
#define GTASK_GENERIC_TASK_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST( (klass), \
                                            GTASK_GENERIC_TASK_TYPE, \
                                            GTaskGenericTaskClass ))

/**
 * returns TRUE if the passed in object is a GTaskGenericTask,
 * FALSE otherwise
 * */
#define GTASK_IS_GENERIC_TASK(obj)         (G_TYPE_CHECK_INSTANCE_TYPE( (obj), \
                                            GTASK_GENERIC_TASK_TYPE ))

/**
 * returns TRUE if the passed in object is a GTaskGenericTaskClass,
 * FALSE otherwise
 */
#define GTASK_IS_GENERIC_TASK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE( (klass), \
                                            GTASK_GENERIC_TASK_TYPE ))

#define GTASK_GENERIC_TASK_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS( (obj), \
                                            GTASK_GENERIC_TASK_TYPE, \
                                            GTaskGenericClass ))
/**
 * An enumeration of the possible activity states a task may have
 */
typedef enum {
    GTASK_ACTIVITY_STATE_ACTIVE    = 1 << 0,
    GTASK_ACTIVITY_STATE_INACTIVE  = 1 << 1,
    GTASK_ACTIVITY_STATE_COMPLETED = 1 << 2
} GTaskActivityState;

#define GTASK_TIME_LEFT_UNKNOWN -1

#define GTASK_ACTIVITY_STATE_TYPE         (gtask_activity_state_get_type())

struct _GTaskGenericTaskPrivate {
    GTaskConnectionGroup *conn_group;

    GString              *application;
    GString              *task_id;

    GString              *title;
    GString              *category;

    GString              *thumbnail_uri;

    GList                *files;

    gfloat                percent_done;
    GTaskActivityState    activity_state;

    glong                 time_left;

    GString              *status_msg;
    GString              *error_msg;

    gboolean              dispose_has_run;
};

struct _GTaskGenericTask {
    GObject parent;
    GTaskGenericTaskPrivate *private;
};

struct _GTaskGenericTaskClass {
    GObjectClass parent;
};

GType gtask_activity_state_get_type( void );

GType gtask_generic_task_get_type( void );

GTaskGenericTask *
gtask_generic_task_new( void );

GTaskGenericTask *
gtask_generic_task_new_with_connection_group( GTaskConnectionGroup *conn_group );

gboolean
gtask_generic_task_serialize( GTaskGenericTask *task );

gboolean
gtask_generic_task_serialize_to( GTaskGenericTask *task,
                                 GTaskConnection *conn );

void
gtask_generic_task_set_title( GTaskGenericTask *task, const gchar *title );

const gchar *
gtask_generic_task_get_title( GTaskGenericTask *task );

void
gtask_generic_task_set_thumbnail_uri( GTaskGenericTask *task,
                                      const gchar *uri );

const gchar*
gtask_generic_task_get_thumbnail_uri( GTaskGenericTask *task );

void
gtask_generic_task_set_percent_done( GTaskGenericTask *task, gfloat percent );

gfloat
gtask_generic_task_get_percent_done( GTaskGenericTask *task );

void
gtask_generic_task_set_activity_state( GTaskGenericTask *task,
                                       GTaskActivityState state );
void
gtask_generic_task_set_activity_state_from_string( GTaskGenericTask *task,
                                                   const gchar *state );

GTaskActivityState
gtask_generic_task_get_activity_state( GTaskGenericTask *task );

const gchar *
gtask_generic_task_get_activity_state_as_string( GTaskGenericTask *task );

void
gtask_generic_task_set_status_message( GTaskGenericTask *task,
                                       const gchar *msg );

const gchar *
gtask_generic_task_get_status_message( GTaskGenericTask *task );

void
gtask_generic_task_set_error_message( GTaskGenericTask *task,
                                      const gchar *msg );

const gchar *
gtask_generic_task_get_error_message( GTaskGenericTask *task );

void
gtask_generic_task_set_application( GTaskGenericTask *task, const gchar *app );

const gchar *
gtask_generic_task_get_application( GTaskGenericTask *task );

void
gtask_generic_task_set_id( GTaskGenericTask *task, const gchar *id );

const gchar *
gtask_generic_task_get_id( GTaskGenericTask *task );

void
gtask_generic_task_set_category( GTaskGenericTask *task, const gchar *cat );

const gchar *
gtask_generic_task_get_category( GTaskGenericTask *task );

void
gtask_generic_task_dump( GTaskGenericTask *task );

void
gtask_generic_task_set_time_left( GTaskGenericTask *task, glong time_left );

glong
gtask_generic_task_get_time_left( GTaskGenericTask *task );

void
gtask_generic_task_add_file( GTaskGenericTask *task, GTaskFile *file );

void
gtask_generic_task_add_files( GTaskGenericTask *task, GList *files );

GList *
gtask_generic_task_get_files( GTaskGenericTask *task );

void
gtask_generic_task_clear_files( GTaskGenericTask *task );

/* @} */

#endif
