/* gTask
 * Copyright (C) 2004 Michael Henson                                       
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef GTASK_PACKET_H
#define GTASK_PACKET_H

#include <glib-2.0/glib-object.h>
#include <gtask/gtask-connection-group.h>
#include <gtask/gtask-connection.h>

/** @addtogroup GTaskPacket */

/* @{ */

typedef struct _GTaskPacket        GTaskPacket;
typedef struct _GTaskPacketPrivate GTaskPacketPrivate;
typedef struct _GTaskPacketClass   GTaskPacketClass;

/** returns the GType of GTaskPacket */
#define GTASK_PACKET_TYPE            (gtask_packet_get_type())

/** casts the passed in object to a GTaskPacket */
#define GTASK_PACKET(obj)            (G_TYPE_CHECK_INSTANCE_CAST( (obj), \
                                      GTASK_PACKET_TYPE, \
                                      GTaskPacket ))

/** casts the passed in object to a GTaskPacketClass */
#define GTASK_PACKET_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST( (klass), \
                                      GTASK_PACKET_TYPE, \
                                      GTaskPacketClass ))

/**
 * returns TRUE if the passed in object is a GTaskPacket,
 * FALSE otherwise
 */
#define GTASK_IS_PACKET(obj)         (G_TYPE_CHECK_INSTANCE_TYPE( (obj), \
                                      GTASK_PACKET_TYPE ))

/**
 * returns TRUE if the passed in object is a GTaskPacketClass,
 * FALSE otherwise
 */
#define GTASK_IS_PACKET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE( (klass), \
                                      GTASK_PACKET_TYPE ))

#define GTASK_PACKET_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS( (obj), \
                                      GTASK_PACKET_TYPE, \
                                      GTaskPacketClass ))


struct _GTaskPacket {
    GObject             parent;
    GTaskPacketPrivate *private;
};

struct _GTaskPacketPrivate {
    GTaskConnectionGroup *conn_group;
    gboolean              dispose_has_run;
};

struct _GTaskPacketClass {
    GObjectClass parent;

    gboolean (*serialize_packet) ( GTaskPacket *packet, GTaskConnection *conn );
};

GType gtask_packet_get_type( void );

gboolean
gtask_packet_serialize( GTaskPacket *packet );

gboolean
gtask_packet_serialize_to( GTaskPacket *packet, GTaskConnection *conn );

GTaskConnectionGroup *
gtask_packet_get_connection_group( GTaskPacket *packet );

void
gtask_packet_set_connection_group( GTaskPacket *packet,
                                   GTaskConnectionGroup *conn_group );

/* @} */

#endif
