/* gTask
 * Copyright (C) 2004 Michael Henson                                       
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <gtask/gtask-query-packet.h>

/** @addtogroup GTaskQueryPacket */

/* @{ */

static gpointer parent_class = NULL;

static void
gtask_query_packet_class_init( GTaskQueryPacketClass *klass );

static void
gtask_query_packet_init( GTaskQueryPacket *packet, gpointer g_class );

static void
gtask_query_packet_finalize( GObject *obj );

static gboolean
gtask_query_packet_serialize_to( GTaskPacket *packet,
                                 GTaskConnection *conn );

GType gtask_query_packet_get_type( void ) {
    static GType type = 0;

    if( type == 0 ) {
        static const GTypeInfo info = {
            sizeof( GTaskQueryPacketClass ),
            NULL,   /* base_init */
            NULL,   /* base_finalize */
            (GClassInitFunc) gtask_query_packet_class_init,   /* class_init */
            NULL,   /* class_finalize */
            NULL,   /* class_data */
            sizeof( GTaskQueryPacket ),
            0,      /* n_preallocs */
            (GInstanceInitFunc) gtask_query_packet_init
        };

        type = g_type_register_static( GTASK_PACKET_TYPE,
                                       "GTaskQueryPacket",
                                       &info,
                                       0 );
    }

    return type;
}

static void
gtask_query_packet_class_init( GTaskQueryPacketClass *klass ) {
    GObjectClass     *gobject_class = G_OBJECT_CLASS( klass );
    GTaskPacketClass *packet_class = GTASK_PACKET_CLASS( klass );

    parent_class = g_type_class_peek_parent( klass );

    gobject_class->finalize = gtask_query_packet_finalize;

    packet_class->serialize_packet = gtask_query_packet_serialize_to;
}

static void
gtask_query_packet_init( GTaskQueryPacket *packet, gpointer g_class ) {
    packet->private = g_new0( GTaskQueryPacketPrivate, 1 );
}

static void
gtask_query_packet_finalize( GObject *obj ) {
    GTaskQueryPacket *packet = GTASK_QUERY_PACKET( obj );

    g_free( packet->private );

    if( G_OBJECT_CLASS( parent_class )->finalize )
        G_OBJECT_CLASS( parent_class )->finalize( obj );
}

/**
 * @brief writes out the xml form of the passed in GTaskQueryPacket to
 *        the passed in GTaskConnection. In general this function
 *        should never be called, except from within the library.
 *        To serialize any packet call gtask_packet_serialize( GTaskPacket * )
 *        instead.
 *
 * @author Michael Henson
 *  
 * @param packet a GTaskQueryPacket
 * @param conn the connection to serialize to
 *
 * @return the success/failure of the operation
 */
static gboolean
gtask_query_packet_serialize_to( GTaskPacket *packet,
                                 GTaskConnection *conn ) 
{
    GTaskQueryPacket   *q_packet;
    xmlOutputBufferPtr  xml_output;
    xmlDocPtr           doc;
    xmlNodePtr          watch_node;

    g_return_val_if_fail( GTASK_IS_QUERY_PACKET( packet ), FALSE );
    g_return_val_if_fail( GTASK_IS_CONNECTION( conn ), FALSE );
    g_return_val_if_fail( gtask_connection_is_connected( conn ), FALSE );

    q_packet = (GTaskQueryPacket *) packet;

    doc = xmlNewDoc( "1.0" );

    if( !doc )
        return FALSE;

    watch_node = xmlNewNode( NULL, "query" );

    if( !watch_node ) {
        xmlFreeDoc( doc );

        return FALSE;
    }

    xmlDocSetRootElement( doc, watch_node );

    xml_output = gtask_connection_get_xml_output_buffer( conn );
    xmlNodeDumpOutput( xml_output, doc, watch_node, 1, 0, NULL );
    xmlOutputBufferFlush( xml_output );

    xmlFreeDoc( doc );

    return TRUE;
}

/**
 * @brief creates a new GTaskQueryPacket
 *
 * @author Michael Henson
 *
 * @return the new GTaskQueryPacket
 */
GTaskQueryPacket *
gtask_query_packet_new( ) {
    return g_object_new( GTASK_QUERY_PACKET_TYPE, NULL );
}

/* @} */
