/* gTask
 * Copyright (C) 2004 Michael Henson                                       
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef GTASK_ROLE_PACKET_H
#define GTASK_ROLE_PACKET_H

#include <gtask/gtask-packet.h>

/** @addtogroup GTaskRolePacket */

/* @{ */

typedef struct _GTaskRolePacket        GTaskRolePacket;
typedef struct _GTaskRolePacketPrivate GTaskRolePacketPrivate;
typedef struct _GTaskRolePacketClass   GTaskRolePacketClass;


/** returns the GType of GTaskRolePacket */
#define GTASK_ROLE_PACKET_TYPE            (gtask_role_packet_get_type())

/** casts the passed in object to a GTaskRolePacket */
#define GTASK_ROLE_PACKET(obj)            (G_TYPE_CHECK_INSTANCE_CAST( (obj), \
                                           GTASK_ROLE_PACKET_TYPE, \
                                           GTaskRolePacket ))

/** casts the passed in object to a GTaskRolePacketClass */
#define GTASK_ROLE_PACKET_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST( (klass), \
                                           GTASK_ROLE_PACKET_TYPE, \
                                           GTaskRolePacketClass ))

/**
 * returns TRUE if the passed in object is a GTaskRolePacket,
 * FALSE otherwise
 */
#define GTASK_IS_ROLE_PACKET(obj)         (G_TYPE_CHECK_INSTANCE_TYPE( (obj), \
                                           GTASK_ROLE_PACKET_TYPE ))

/**
 * returns TRUE if the passed in object is a GTaskRolePacketClass,
 * FALSE otherwise
 */
#define GTASK_IS_ROLE_PACKET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE( (klass), \
                                           GTASK_ROLE_PACKET_TYPE ))

#define GTASK_ROLE_PACKET_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS( (obj), \
                                           GTASK_ROLE_PACKET_TYPE, \
                                           GTaskRolePacketClass ))

typedef enum  {
    GTASK_ROLE_NONE,        ///< no role has been specified
    GTASK_ROLE_PROXY,       ///< the proxy role -- callbacks, etc are sent back to another gtask server for exectution
    GTASK_ROLE_REPORTER,    ///< the reporter role -- the ui displaying tasks
    GTASK_ROLE_PROVIDER     ///< the provider role -- the program creating tasks
} GTaskRole;

#define GTASK_ROLE_TYPE                   (gtask_role_get_type())


struct _GTaskRolePacket {
    GTaskPacket             parent;
    GTaskRolePacketPrivate *private;
};

struct _GTaskRolePacketPrivate {
    GTaskRole role;
};

struct _GTaskRolePacketClass {
    GTaskPacketClass parent;
};

GType gtask_role_get_type( void );

GType gtask_role_packet_get_type( void );

GTaskRolePacket *
gtask_role_packet_new( void );

GTaskRolePacket *
gtask_role_packet_new_with_role( GTaskRole role );

GTaskRole
gtask_role_packet_get_role( GTaskRolePacket *packet );

void
gtask_role_packet_set_role( GTaskRolePacket *packet, GTaskRole role );

void
gtask_role_packet_set_role_from_name( GTaskRolePacket *packet,
                                      const char *name );

const char *
gtask_role_packet_get_role_name( GTaskRolePacket *packet );

GTaskRole
gtask_role_from_name( const char *name );

const char *
gtask_role_name( GTaskRole role );

/* @} */

#endif
