/* gTask
 * Copyright (C) 2004 Michael Henson                                       
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef GTASK_STREAM_PARSER_H
#define GTASK_STREAM_PARSER_H

#include <glib.h>
#include <glib-2.0/glib-object.h>
//#include <gtask/gtask-packet.h>
#include <libxml/xmlreader.h>

/** @addtogroup GTaskStreamParser */

/* @{ */

typedef struct _GTaskStreamParser        GTaskStreamParser;
typedef struct _GTaskStreamParserPrivate GTaskStreamParserPrivate;
typedef struct _GTaskStreamParserClass   GTaskStreamParserClass;

/** returns a GType of GTaskStreamParser */
#define GTASK_STREAM_PARSER_TYPE           (gtask_stream_parser_get_type())

/** casts the passed in object to a GTaskStreamParser */
#define GTASK_STREAM_PARSER(obj)           (G_TYPE_CHECK_INSTANCE_CAST( (obj), \
                                            GTASK_STREAM_PARSER_TYPE, \
                                            GTaskStreamParser ))

/** casts the passed in object to a GTaskStreamParserClass */
#define GTASK_STREAM_PARSER_CLASS(kclass)  (G_TYPE_CHECK_CLASS_CAST( (klass), \
                                            GTASK_STREAM_PARSER_TYPE, \
                                            GTaskStreamParserClass ))

/**
 * returns TRUE is the passed in object is a GTaskStreamParser,
 * FALSE otherwise
 */
#define GTASK_IS_STREAM_PARSER(obj)        (G_TYPE_CHECK_INSTANCE_TYPE( (obj), \
                                            GTASK_STREAM_PARSER_TYPE ))

/**
 * returns TRUE if the passed in object is a GTaskStreamParser,
 * FALSE otherwise
 */
#define GTASK_IS_STREAM_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE( (klass), \
                                              GTASK_STREAM_PARSER_TYPE ))

#define GTASK_STREAM_PARSER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS( (obj), \
                                             GTASK_STREAM_PARSER_TYPE, \
                                             GTaskStreamParserClass ))

struct _GTaskStreamParser {
    GObject                   parent;
    GTaskStreamParserPrivate *private;
};

struct _GTaskStreamParserClass {
    GObjectClass parent;
};

typedef enum {
    GTASK_STREAM_PARSER_ERROR_NONE,         ///< there is no error
    GTASK_STREAM_PARSER_ERROR_SYNTAX_ERROR  ///< a syntax error has occurred
} GTaskStreamParserError;

GType
gtask_stream_parser_get_type( void );

GTaskStreamParser *
gtask_stream_parser_new( void );

//GTaskPacket *
GObject *
gtask_stream_parser_get_next_packet( GTaskStreamParser *parser );

gboolean
gtask_stream_parser_has_error( GTaskStreamParser *parser );

GTaskStreamParserError
gtask_stream_parser_get_error( GTaskStreamParser *parser );

gboolean
gtask_stream_parser_at_eof( GTaskStreamParser *parser );

gboolean
gtask_stream_parser_has_packets( GTaskStreamParser *parser );

gboolean
gtask_stream_parser_push_data( GTaskStreamParser *parser, char *buff, int len );

void
gtask_stream_parser_reset_state( GTaskStreamParser *parser );

/* @} */

#endif
