/* gTask
 * Copyright (C) 2004 Michael Henson                                       
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef GTASK_WATCH_PACKET_H
#define GTASK_WATCH_PACKET_H

#include <gtask/gtask-packet.h>

/** @addtogroup GTaskWatchPacket */

/* @{ */

typedef struct _GTaskWatchPacket        GTaskWatchPacket;
typedef struct _GTaskWatchPacketPrivate GTaskWatchPacketPrivate;
typedef struct _GTaskWatchPacketClass   GTaskWatchPacketClass;


/** returns the GType of GTaskWatchPacket */
#define GTASK_WATCH_PACKET_TYPE            (gtask_watch_packet_get_type())

/** casts the passed in object to a GTaskWatchPacket */
#define GTASK_WATCH_PACKET(obj)            (G_TYPE_CHECK_INSTANCE_CAST( (obj), \
                                            GTASK_WATCH_PACKET_TYPE, \
                                            GTaskWatchPacket ))

/** casts the passed in object to a GTaskWatchPacketClass */
#define GTASK_WATCH_PACKET_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST( (klass), \
                                            GTASK_WATCH_PACKET_TYPE, \
                                            GTaskWatchPacketClass ))

/**
 * returns TRUE if the passed in object is a GTaskWatchPacket,
 * FALSE otherwise
 */
#define GTASK_IS_WATCH_PACKET(obj)         (G_TYPE_CHECK_INSTANCE_TYPE( (obj), \
                                            GTASK_WATCH_PACKET_TYPE ))

/**
 * returns TRUE if the passed in object is a GTaskWatchPacketClass,
 * FALSE otherwise
 */
#define GTASK_IS_WATCH_PACKET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE( (klass), \
                                            GTASK_WATCH_PACKET_TYPE ))

#define GTASK_WATCH_PACKET_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS( (obj), \
                                            GTASK_WATCH_PACKET_TYPE, \
                                            GTaskWatchPacketClass ))

struct _GTaskWatchPacket {
    GObject                  parent;
    GTaskWatchPacketPrivate *private;
};

struct _GTaskWatchPacketPrivate {
    GString *watch_id;
};

struct _GTaskWatchPacketClass {
    GTaskPacketClass parent;
};

GType gtask_watch_packet_get_type( void );

GTaskWatchPacket *
gtask_watch_packet_new( void );

GTaskWatchPacket *
gtask_watch_packet_new_with_watch_id( const char *watch_id );

const char *
gtask_watch_packet_get_watch_id( GTaskWatchPacket *packet );

void
gtask_watch_packet_set_watch_id( GTaskWatchPacket *packet,
                                 const char *watch_id );

/* @} */

#endif
